@@ -1,4 +1,5 @@
 import gevent
+import gipc
 from gevent.pool import Group
 
 
@@ -14,7 +15,7 @@ def echo_queue(q):
 
 
 def spawn_worker(conf):
-    """Some sugar for to wrap up all of your greenlets."""
+    """Some sugar to wrap up all of your greenlets."""
     group = Group()
     for args in conf:
         group.spawn(*args)
@@ -23,3 +24,12 @@ def spawn_worker(conf):
             gevent.sleep(1)
     except KeyboardInterrupt:
         pass
+
+
+def spawn_processes(confs):
+    """Spawn subprocesses with a config similar to spawn_worker."""
+    processes = []
+    for conf in confs:
+        p = gipc.start_process(target=conf[0], args=tuple(conf[1:]))
+        processes.append(p)
+    return processes
